@@ -69,8 +69,13 @@ class PCA:
         start = int(time())
         found = False
         if fast:
-            CONST.DISCOVERY_TIME = 10
-            CONST.DISCOVERY_TIMEOUT = 10
+            CONST.DISCOVERY_TIME = 5
+            CONST.DISCOVERY_TIMEOUT = 5
+        for device in self._known_devices:
+            self._devices[device]['state'] = 0
+            self._devices[device]['consumption'] = 0
+            self._devices[device]['power'] = 0
+
         while not (int(time()) - start > CONST.DISCOVERY_TIMEOUT) or not (int(time()) - start > CONST.DISCOVERY_TIME or found):
             line = self._serial.readline().decode("utf-8")
             if len(line) > 1:
